@@ -2,6 +2,10 @@
 package MooseX::AttributeHelpers::Meta::Method::Provided;
 use Moose;
 
+our $VERSION   = '0.16';
+$VERSION = eval $VERSION;
+our $AUTHORITY = 'cpan:STEVAN';
+
 extends 'Moose::Meta::Method';
 
 1;
@@ -45,4 +49,4 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
